@@ -1,6 +1,6 @@
 package Device::Blkid::E2fsprogs;
 
-our $VERSION = '0.38';
+our $VERSION = '0.40';
 
 use 5.008000;
 use strict;
@@ -106,23 +106,22 @@ Device::Blkid::E2fsprogs - Perl interface to e2fsprogs-based libblkid (v1.33 - v
 
 =head3 Important Note
 
-This library is compatible with those versions of libblkid which shipped as a part of the
+This library is compatible with those versions of libblkid which were bundled with the
 e2fsprogs package, i.e., those versions of the library numbered 1.xx. While this package
-should be fully compliant with the newer util-linux-ng based versions of the libblkid interface,
-it is not recommended that you use it; without modifications to the configuration scripts, it
-will fail to install on such systems in any event.
+should be fully compliant with the newer util-linux-ng based versions of the libblkid
+interface, it is not recommended that you use it; without modifications to the configuration
+scripts, it will fail to install on such systems in any event.
 
 If the target system is running the util-linux-ng versions of libblkid, indicated by a 2.x
-version number, you would be advised to use Bastian Friedrich's L<Device::Blkid> package
-instead. Those versions of the library feature a richer and more robust interface which this
-package does not support. This package is generally recommended in those cases where you are
-bound by constraint to the e2fsprogs-based versions of the libblkid library.
+version number, you would be advised to use Bastian Friedrich's L<Device::Blkid> module
+rather than this one. Those versions of the library feature a larger and more complete interface
+which this extension does not support. It is recommended that this extension be used only in
+those cases where you are bound by some contraint to the e2fsprogs-based versions of the
+libblkid library.
 
 Finally, this extension has been implemented somewhat differently than Bastian's util-linux-ng
-build of the library. He opted to keep much of his logic and processing in XSUB, mine is done
-mostly in C; I have only used XSUB for my straight glue, everything else I have kept in C and
-have used the Perl API. This should not to be taken as any sort of statement about XS/XSUB but
-instead is simply a reflection of my own personal background and tastes.
+libblkid interface. He opted to keep much of his logic and processing in XSUB, mine is done
+mostly in C; I have only used XSUB as glue.
 
 =head1 DESCRIPTION
 
@@ -142,45 +141,45 @@ to this cache file is one way in which unpriviledged users who do not have read
 particular block device can gain access to this information. Users with the necessary access
 can always opt to probe the block device directly for this information.
 
-This Perl extension to e2fsprogs-based versions of the libblkid library provides for the same
-functionality exposed by the C interface. As was noted, it does not support the larger and
-more robust API which has been added to the libblkid library since its inclusion in the
-util-linux-ng package. To access these newer versions of the library, please see the
-L<Device::Blkid> package.
+This Perl extension exposes the same functionality offered up by the C libblkid interface.
+As was noted, it does not support the considerably larger set of calls which are a part of
+the util-linux-ng versions of libblkid. To properly support usage of these versions, and its
+considerably larger API, please see the L<Device::Blkid> package.
 
 I have endeavored to provide a more Perlish interface to the library rather than just do
 straight mappings or wrappers over the C functions. Most library calls will return an undef
-on failure. Those which return data structures which are allocated in memory will throw an
-exception catchable via an C<eval/if>. Furthermore, several of the original library calls which
-were passed in modifiable pointer arguments now return Perl hash representations of complex
-types where this made sense. See the interface documentation below for details on each call.
+on failure. Those which allocate and return data structures will throw an exception catchable
+via the usual C<eval/if> construct. Furthermore, several of the original library calls which
+relied on modifiable pointer arguments now return Perl hash representations of complex types
+where this made sense. See the interface documentation below for details on each call.
 
 Please refer to the F<README> file in the package archive for instructions should you encounter
 any problems while using this software package.
 
+=head2 INSTALLATION NOTES
+
 It is worth noting that between versions 1.33 and 1.41.x, the entire period which libblkid
 was shipping as a part of the e2fsprogs package, the number of calls present in the API
 expanded from 17 in the original release of the library back in 2003 to 25 by the time it
 was migrated over to the util-linux-ng package in early 2009. This extension supports dynamic
 detection of the libblkid version on the target system from version 1.36 onward. In the event
 that a proper determination of version cannot be obtained and the library is confirmed to in
-fact be on the system, a default baseline version of 1.33 will be generated which will be
-compliant with all possible versions of libblkid which shipped with the e2fsprogs package.
+fact be on the system, a default baseline version target of 1.33 will be generated which will
+be compliant with all of the possible versions of libblkid which shipped with the e2fsprogs
+package.
 
-=head2 INSTALLATION NOTES
-
-This package has made use of a customized L<Devel::CheckLib> module and F<Makefile.PL> in an
-attempt to dynamically detect the version of libblkid currently installed on the target
-system and to then generate a PerlXS interface which directly targets and matches the interface
-of that libblkid version. This process is expected to work on all versions of libblkid later
-than v1.35. On versions 1.33 through to 1.35, a default baseline target for the v1.33 API is
-configured for build. Should you have any problems with this process, evident either in running
-the F<Makefile.PL> or in running make against the resulting F<Makefile>, please see the F<Makefile.PL>
-for hints on troubleshooting. If you wish to report any problems with this version detection,
-please include any output from the installation process as well as a copy of your
+This extension has made use of a customized L<Devel::CheckLib> module in concert with the
+F<Makefile.PL> in order to dynamically detect the version of libblkid currently installed
+on the target system and to then generate a Perl XS interface which directly targets and matches
+the interface of that libblkid version. This process is expected to work on all versions of
+libblkid later than v1.35. On versions 1.33 through to 1.35, a default baseline target for the
+v1.33 API is configured for build. Should you have any problems with this process, evident either
+in running the F<Makefile.PL> or in running make against the resulting F<Makefile>, please see the
+F<Makefile.PL> for hints on troubleshooting. If you wish to report any problems with this version
+detection, please include any output from the installation process as well as a copy of your
 F</usr/include/blkid/blkid.h> file. Finally, in cases where you are running version 1.34 or 1.35,
-and where you require inclusion of the L</known_fstype> function in this package, you will be
-required to manually modify the F<Makefile.PL> to achieve this end.
+and where you require inclusion of the L</known_fstype()> function in your build, you will be
+required to modify the F<Makefile.PL> to achieve this end.
 
 For additional details regarding dynamic library version detection, please refer to the
 F<README> file at the top level of this package.
@@ -189,10 +188,10 @@ F<README> file at the top level of this package.
 
 L<E2fsprogs v1.33-v1.41.4|http://e2fsprogs.sourceforge.net/>
 
-While this package is compatible with any version of e2fsprogs-based libblkid, dynamic version
-detection will only work on versions 1.36 and newer. In cases where the proper version cannot
-be detected, a baseline version of v1.33 will be generated and this version target will be
-compatible with whatever version happens to be on the target system.
+While this package is compatible with any version of libblkid from the e2fsprogs package, dynamic
+version detection will only work on versions 1.36 and newer. In cases where the proper version
+cannot be detected properly during configuration, a baseline build which targets version 1.33 of
+libblkid will be configured which is compliant with anything which might be on the target system.
 
 =head2 EXPORT
 
@@ -232,24 +231,25 @@ Get a valid device structure, either from the cache or by probing the block devi
 
 All function calls detailed below also list the version of libblkid in which they first appeared
 as a part of the library. As has been noted above, all of these calls should also be valid in the
-newer util-linux-ng versions of this interface.
+newer util-linux-ng versions of this interface which is reportedly completely backward compatible
+with the older library.
 
 =over 4
 
 =item C<put_cache($cache)>
 
-Write any changes to the blkid cache file and explicitly frees associated resources. L</put_cache()>
+Write any changes to the blkid cache file and explicitly free associated resources. L</put_cache()>
 should be called after you have been doing any work with a cache object. Note, the cache object is freed
 by this call and as such must not be used by any subsequent operations. Further calls to L</put_cache()>
-on an already deallocated cache structure result in a segfault from the libblkid library so guard against
-this.
+on an already deallocated cache structure result in a segfault from the libblkid library so take guard
+against this.
 
 C<v1.33>
 
 =item C<get_cache($filename)>
 
 Given a path to a cache file, return a blkid cache object reference. This reference is of type
-C<Device::Blkid::E2fsprogs::Cache>. As with other calls which allocate object types, this call
+C<Device::Blkid::E2fsprogs::Cache>. This call, as with other calls which allocate an object type,
 throws an exception on failure.
 
 C<v1.33>
@@ -263,15 +263,15 @@ C<v1.40>
 =item C<dev_devname($device)>
 
 Given a blkid device object, returns a string representation of the device (e.g., /dev/sda3), or undef
-on fail. Device objects are of type C<Device::Blkid::E2fsprogs::Device>.
+on fail. Device object arguments must be of type C<Device::Blkid::E2fsprogs::Device>.
 
 C<v1.33>
 
 =item C<dev_iterate_begin($cache)>
 
 Returns a device iterator object on the specified device cache. Device iterator objects are of type
-C<Device::Blkid::E2fsprogs::DevIter>. As in the case of other allocated types, this call throws an
-exception on fail.
+C<Device::Blkid::E2fsprogs::DevIter>. As in the case of other calls which return allocated object
+types, this call throws an exception on fail.
 
 C<v1.33>
 
@@ -441,7 +441,7 @@ C<v1.36>
 =item C<get_library_version()>
 
 Returns a hash reference containing the libblkid library version and release date as well as a raw integer
-representation of the standard dotted-decimal formatted version string (see L</parse_version_string> above).
+representation of the standard dotted-decimal formatted version string (see L</parse_version_string()> above).
 Returns undef on failure.
 
   { version => '1.41.4', date => '27-Jan-2009', raw => '1414' }  
@@ -479,11 +479,13 @@ of Perl 5 you may have available.
 
 =head1 TODO
 
-Cleanup preprocessor code when everything checks out stable.
+Eliminating redundant calls and implement a more Perlish feel.
 
-Consider eliminating redundant calls and implementing an even more 'Perlish' design.
+Implement L</devno_to_devname()> with a variadic parameter list so that it will accept
+both a devno and major/minor parameter list.
 
-Test scripts; handle multiple version targets.
+Test scripts; handle multiple version targets so that additional unit tests can be written
+to target additional library calls.
 
 =head1 CREDITS
 
@@ -497,9 +499,8 @@ hacked it up a little bit to manage my dynamic version checks and build, hope yo
 
 Thanks to Tom Erskine for your insight and experience in all things Perl.
 
-I would also like to thank Larry McInnis for the loan of some hardware on which to develop
-this module. Most everything I have had been tied up and developing on the latest and greatest
-version of Debian didn't make much sense.
+Thanks to Larry McInnis for the hardware on which I installed several dated versions of
+Fedora Core on which I developed and tested this extension.
 
 =head1 BUGS
 
@@ -508,11 +509,11 @@ What's a bug? :)
 No known bugs at this time. That said, this module is largely written in C and does contain
 a number of memory allocations. While these allocations are done inside of libblkid itself,
 I do make every attempt to free the memory explicitly when I am done with it. That said, leaks
-are possible. Please report any issues as is detailed above.
+are always a possibility. Please report any issues which you might have as is detailed above.
 
 =head1 DIRECTION
 
-This is an early release of this module. It and its interface are subject to change at any
-time. Please refer to all package documentation before reporting any problems.
+This is an early release of this module. This extension and its interface are subject to change
+at any time. Please refer to all package documentation before reporting any problems.
 
 =Cut
